==> knative-model-5.7.2-sources.jar: io/fabric8/knative/flows/v1/ParallelChannelStatus.java <==

package io.fabric8.knative.flows.v1;

import java.util.HashMap;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.model.Container;
import io.fabric8.kubernetes.api.model.ContainerPort;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.Volume;
import io.fabric8.kubernetes.api.model.VolumeMount;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import lombok.EqualsAndHashCode;
import lombok.ToString;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "channel",
    "ready"
})
@JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = true, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @BuildableReference(ObjectMeta.class),
    @BuildableReference(io.fabric8.kubernetes.api.model.ObjectReference.class),
    @BuildableReference(LabelSelector.class),
    @BuildableReference(Container.class),
    @BuildableReference(EnvVar.class),
    @BuildableReference(ContainerPort.class),
    @BuildableReference(Volume.class),
    @BuildableReference(VolumeMount.class)
})
public class ParallelChannelStatus implements KubernetesResource
{

    @JsonProperty("channel")
    private io.fabric8.kubernetes.api.model.ObjectReference channel;
    @JsonProperty("ready")
    private Condition ready;
    @JsonIgnore
    private Map<String, Object> additionalProperties = new HashMap<String, Object>();

    /**
     * No args constructor for use in serialization
     * 
     */
    public ParallelChannelStatus() {
    }

    /**
     * 
     * @param ready
     * @param channel
     */
    public ParallelChannelStatus(io.fabric8.kubernetes.api.model.ObjectReference channel, Condition ready) {
        super();
        this.channel = channel;
        this.ready = ready;
    }

    @JsonProperty("channel")
    public io.fabric8.kubernetes.api.model.ObjectReference getChannel() {
        return channel;
    }

    @JsonProperty("channel")
    public void setChannel(io.fabric8.kubernetes.api.model.ObjectReference channel) {
        this.channel = channel;
    }

    @JsonProperty("ready")
    public Condition getReady() {
        return ready;
    }

    @JsonProperty("ready")
    public void setReady(Condition ready) {
        this.ready = ready;
    }

    @JsonAnyGetter
    public Map<String, Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperty(String name, Object value) {
        this.additionalProperties.put(name, value);
    }

}

==> knative-model-5.7.3-sources.jar: io/fabric8/knative/flows/v1/ParallelChannelStatus.java <==

package io.fabric8.knative.flows.v1;

import java.util.HashMap;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.model.Container;
import io.fabric8.kubernetes.api.model.ContainerPort;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.Volume;
import io.fabric8.kubernetes.api.model.VolumeMount;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import lombok.EqualsAndHashCode;
import lombok.ToString;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "channel",
    "ready"
})
@JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = false, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @BuildableReference(ObjectMeta.class),
    @BuildableReference(io.fabric8.kubernetes.api.model.ObjectReference.class),
    @BuildableReference(LabelSelector.class),
    @BuildableReference(Container.class),
    @BuildableReference(EnvVar.class),
    @BuildableReference(ContainerPort.class),
    @BuildableReference(Volume.class),
    @BuildableReference(VolumeMount.class)
})
public class ParallelChannelStatus implements KubernetesResource
{

    @JsonProperty("channel")
    private io.fabric8.kubernetes.api.model.ObjectReference channel;
    @JsonProperty("ready")
    private Condition ready;
    @JsonIgnore
    private Map<String, Object> additionalProperties = new HashMap<String, Object>();

    /**
     * No args constructor for use in serialization
     * 
     */
    public ParallelChannelStatus() {
    }

    /**
     * 
     * @param ready
     * @param channel
     */
    public ParallelChannelStatus(io.fabric8.kubernetes.api.model.ObjectReference channel, Condition ready) {
        super();
        this.channel = channel;
        this.ready = ready;
    }

    @JsonProperty("channel")
    public io.fabric8.kubernetes.api.model.ObjectReference getChannel() {
        return channel;
    }

    @JsonProperty("channel")
    public void setChannel(io.fabric8.kubernetes.api.model.ObjectReference channel) {
        this.channel = channel;
    }

    @JsonProperty("ready")
    public Condition getReady() {
        return ready;
    }

    @JsonProperty("ready")
    public void setReady(Condition ready) {
        this.ready = ready;
    }

    @JsonAnyGetter
    public Map<String, Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperty(String name, Object value) {
        this.additionalProperties.put(name, value);
    }

}
